import { defineComponent } from 'vue'
import styles from './index.module.less'
import ColHeader from '@/components/col-header'
import { Button, Icon, Popup, RadioGroup, Sticky, Radio, Tag } from 'vant'
import ColSearch from '@/components/col-search'
import PracticeItem from './practice-item'
import { practiceNumType, classPriceType, scoreType } from './practice'

export default defineComponent({
  name: 'practiceClass',
  data() {
    return {
      searchStatus: false,
      chargeType: 0
    }
  },
  methods: {
    onSearch(_file: any) {
      console.log(_file)
    }
  },
  render() {
    return (
      <>
        <Sticky style={{ background: 'var(--van-primary)' }}>
          <ColHeader
            title="陪练课"
            isFixed={false}
            border={false}
            background="var(--van-primary)"
            color="#fff"
          />
          <ColSearch
            placeholder="请输入老师名称/课程名称"
            inputBackground="white"
            background="var(--van-primary)"
            onSearch={this.onSearch}
          />
          <div class={styles.filterSection}>
            <div>
              <Button
                class={[styles.btn]}
                type="primary"
                size="small"
                round
                plain
              >
                全部
                <Icon
                  classPrefix="iconfont"
                  name="down"
                  size={8}
                  style={{ marginLeft: '4px' }}
                  color="var(--van-primary)"
                />
              </Button>
              <Button class={[styles.btn]} size="small" round plain>
                30天内未约满
              </Button>
            </div>
            <div>
              <div
                class={styles.dataItem}
                onClick={() => {
                  this.searchStatus = !this.searchStatus
                }}
              >
                筛选
                <Icon
                  classPrefix="iconfont"
                  name="down"
                  size={8}
                  style={{ marginLeft: '4px' }}
                  color="var(--van-primary)"
                />
              </div>
            </div>
          </div>
        </Sticky>

        <div class={styles.practiceList}>
          {[1, 2, 3].map(item => (
            <PracticeItem />
          ))}
        </div>

        <Popup
          show={this.searchStatus}
          position="bottom"
          round
          closeable
          onClose={() => (this.searchStatus = false)}
        >
          <div class={styles.filterTitle}>全部筛选</div>
          <div class={styles.searchResult}>
            <div class={styles.searchTitle}>陪练课数</div>
            <RadioGroup
              class={styles['radio-group']}
              modelValue={this.chargeType}
              onUpdate:modelValue={val => (this.chargeType = val)}
            >
              {Object.keys(practiceNumType).map((item: string) => {
                const isActive = Number(item) === Number(this.chargeType)
                const type = isActive ? 'primary' : 'default'
                return (
                  <Radio class={styles.radio} name={item}>
                    <Tag size="large" plain={isActive} type={type} round>
                      {practiceNumType[item]}
                    </Tag>
                  </Radio>
                )
              })}
            </RadioGroup>

            <div class={styles.searchTitle}>课时单价</div>
            <RadioGroup
              class={styles['radio-group']}
              modelValue={this.chargeType}
              onUpdate:modelValue={val => (this.chargeType = val)}
            >
              {Object.keys(practiceNumType).map((item: string) => {
                const isActive = Number(item) === this.chargeType
                const type = isActive ? 'primary' : 'default'
                return (
                  <Radio class={styles.radio} name={item}>
                    <Tag size="large" plain={isActive} type={type} round>
                      {practiceNumType[item]}
                    </Tag>
                  </Radio>
                )
              })}
            </RadioGroup>

            <div class={styles.searchTitle}>评分</div>
            <RadioGroup
              class={styles['radio-group']}
              modelValue={this.chargeType}
              onUpdate:modelValue={val => (this.chargeType = val)}
            >
              {Object.keys(practiceNumType).map((item: string) => {
                const isActive = Number(item) === this.chargeType
                const type = isActive ? 'primary' : 'default'
                return (
                  <Radio class={styles.radio} name={item}>
                    <Tag size="large" plain={isActive} type={type} round>
                      {practiceNumType[item]}
                    </Tag>
                  </Radio>
                )
              })}
            </RadioGroup>
          </div>
          <Sticky offsetBottom={0} position="bottom">
            <div class="btnGroup btnMore">
              <Button type="primary" plain round>
                重置
              </Button>
              <Button type="primary" round>
                确认
              </Button>
            </div>
          </Sticky>
        </Popup>
      </>
    )
  }
})
