import request from '@/helpers/request'
import {
  Button,
  Cell,
  CellGroup,
  Icon,
  RadioGroup,
  Radio,
  Dialog,
  Toast
} from 'vant'
import { defineComponent, PropType } from 'vue'
import styles from './index.module.less'

interface IOrderInfo {
  orderNo: string | number
  actualPrice: string | number
}

export default defineComponent({
  name: 'payment',
  props: {
    modelValue: {
      type: Boolean,
      default: false
    },
    orderInfo: {
      type: Object as PropType<IOrderInfo>,
      default: {
        orderNo: '',
        actualPrice: 0
      }
    },
    onBackOut: {
      type: Function,
      default: () => {}
    }
  },
  data() {
    return {
      payType: 'zfb',
      pay_channel: ''
    }
  },
  methods: {
    onClose() {
      Dialog.confirm({
        message: '是否放弃本次付款',
        confirmButtonText: '继续付款',
        cancelButtonText: '放弃'
      })
        .then(() => {})
        .catch(async () => {
          try {
            await request.post('/api-student/userOrder/orderCancel', {
              data: {
                orderNo: this.orderInfo.orderNo
              }
            })
            this.$emit('update:modelValue', false)
            this.$router.go(-1)
            this.onBackOut && this.onBackOut()
          } catch {}
        })
    },
    async onSubmit() {
      // 支付...
      // const pt = this.payType
      // ua = window.navigator.userAgent.toLowerCase()
      // 判断当前浏览器
      // if (ua.indexOf('micromessenger') != -1) {
      //   // 微信浏览器
      //   if (pt == 'zfb') {
      //     this.pay_channel = 'alipay_qr'
      //   } else if (pt == 'wx') {
      //     this.pay_channel = 'wx_pub'
      //   }
      // } else if (ua.indexOf('alipayclient') != -1) {
      //   // 支付宝浏览器
      //   if (pt == 'zfb') {
      //     this.pay_channel = 'alipay_wap'
      //     // 支付宝 H5 支付
      //   } else if (pt == 'wx') {
      //     this.pay_channel = 'wx_pub'
      //   }
      // } else {
      //   if (pt == 'zfb') {
      //     this.pay_channel = 'alipay_qr'
      //   } else if (pt == 'wx') {
      //     this.pay_channel = 'wx_pub'
      //   }
      // }
      try {
        const res = await request.post('/api-student/userOrder/orderPay', {
          data: {
            orderNo: this.orderInfo.orderNo,
            payChannel: this.payType
          }
        })
        // console.log(res)
        postMessage({
          api: 'paymentOrder',
          content: {
            orderNo: this.orderInfo.orderNo,
            payInfo: `alipays://platformapi/startapp?saId=10000007&qrcode=${res.data.pay_info}`
          }
        })
        // pay_info
        Toast.loading({
          message: '支付中...',
          forbidClick: true,
          duration: 3000,
          loadingType: 'spinner',
          onClose: () => {
            this.$emit('update:modelValue', false)
            this.$router.replace({
              path: '/tradeDetail',
              query: {
                orderNo: this.orderInfo.orderNo
              }
            })
          }
        })
        this.$emit('update:modelValue', false)
      } catch {}
    }
  },
  render() {
    return (
      <div class={styles.payment}>
        <Icon onClick={this.onClose} name="cross" size={20} />
        <div class={[styles.title, 'van-hairline--bottom']}>选择支付方式</div>

        <div class={styles.payAmount}>
          <p>应付金额</p>
          <div class={styles.amount}>
            {(this as any).$filters.moneyFormat(this.orderInfo.actualPrice)}
            <span>元</span>
          </div>
        </div>
        <RadioGroup v-model={this.payType}>
          <CellGroup border={false}>
            <Cell
              title="支付宝支付"
              border={false}
              center
              onClick={() => {
                this.payType = 'alipay'
              }}
              v-slots={{
                icon: () => <Icon name="alipay" color="#009fe9" size={22} />,
                'right-icon': () => <Radio name="alipay" />
              }}
            ></Cell>
            <Cell
              title="微信支付"
              border={false}
              center
              onClick={() => {
                this.payType = 'wx_lite'
              }}
              v-slots={{
                icon: () => (
                  <Icon name="wechat-pay" color="#15c434" size={22} />
                ),
                'right-icon': () => <Radio name="wx_lite" />
              }}
            ></Cell>
          </CellGroup>
        </RadioGroup>

        <div class={styles.blank}></div>
        <Button type="primary" block onClick={this.onSubmit}>
          确认支付
        </Button>
      </div>
    )
  }
})
